@@ -54,7 +54,7 @@ class Order:
         "_break_type",
         "_reason",
         "_result",
-        "_message"
+        "_message",
     ]
 
     def __init__(
@@ -102,8 +102,6 @@ class Order:
             self._is_live: bool = order_data["is_cancelled"]
         if "is_cancelled" in order_data:
             self._is_cancelled = order_data["is_cancelled"]
-        if "reason" in order_data:
-            self._reason: str = order_data["reason"]
         if "is_hidden" in order_data:
             self._is_hidden: bool = order_data["is_hidden"]
         if "was_forced" in order_data:
@@ -156,6 +154,10 @@ class Order:
             self._break_type: str = order_data["break"]
         if "result" in order_data:
             self._result: str = order_data["result"]
+        if "reason" in order_data:
+            self._reason: str = order_data["reason"]
+        if "message" in order_data:
+            self._message: str = order_data["message"]
 
     @property
     def order_id(self) -> Union[str, Dict[int, bool]]:
